// TI File $Revision: /main/8 $
// Checkin $Date: April 2, 2007   17:42:55 $
//###########################################################################
//
// FILE:   Example_280xAdcSeq_ovdTest.c
//
// TITLE:  DSP280x ADC Seq Override mode Test.
//
// ASSUMPTIONS:
//
//    This program requires the DSP280x header files.
//
//    Make sure the CPU clock speed is properly defined in
//    DSP280x_Examples.h before compiling this example.
//
//    Connect the signal to be converted to Channel A0.
//
//    As supplied, this project is configured for "boot to SARAM"
//    operation.  The 280x Boot Mode table is shown below.
//    For information on configuring the boot mode of an eZdsp,
//    please refer to the documentation included with the eZdsp,
//
//       Boot      GPIO18     GPIO29    GPIO34
//       Mode      SPICLKA    SCITXDA
//                 SCITXB
//       -------------------------------------
//       Flash       1          1        1
//       SCI-A       1          1        0
//       SPI-A       1          0        1
//       I2C-A       1          0        0
//       ECAN-A      0          1        1
//       SARAM       0          1        0  <- "boot to SARAM"
//       OTP         0          0        1
//       I/0         0          0        0
//
//
// DESCRIPTION:
//
//    Channel A0 is converted forever and logged in a buffer (SampleTable)
//    Using sequencer1 in sequencer override mode. Sequencer is Sequential mode
//    with sample rate of 1/(3*80ns) =4.17MHz (for 100 MHz devices) or of
//    1/(3*133ns) = 2.51 MHz (for 60 MHz devices)
//
//    Open a memory window to SampletTable to observe the buffer
//    RUN for a while and stop and see the table contents.
//
//       Watch Variables:
//          SampleTable - Log of converted values.
//          GPIO34      - Toggles on every ADC sequencer flag
//
//###########################################################################
//
// Original source by: S.S.
//
// $TI Release: DSP280x Header Files V1.50 $
// $Release Date: September 10, 2007 $
//###########################################################################

#include "DSP280x_Device.h"     // DSP280x Headerfile Include File
#include "DSP280x_Examples.h"   // DSP280x Examples Include File

// Determine when the shift to right justify the data takes place
// Only one of these should be defined as 1.
// The other two should be defined as 0.
#define POST_SHIFT   0  // Shift results after the entire sample table is full
#define INLINE_SHIFT 1  // Shift results as the data is taken from the results regsiter
#define NO_SHIFT     0  // Do not shift the results

// ADC start parameters
#define ADC_MODCLK 0x4   // HSPCLK = SYSCLKOUT/2*ADC_MODCLK2 = 100/(2*4)      = 12.5 MHz
                         //    for 60 MHz devices:    HSPCLK =  60/(2*4)      =  7.5 MHz
#define ADC_CKPS   0x0   // ADC module clock = HSPCLK/1      = 12.5MHz/(1)    = 12.5 MHz
                         //    for 60 MHz devices: ADC module clk = 7.5MHz/(1)=  7.5 MHz
#define ADC_SHCLK  0x1   // S/H width in ADC module periods                   = 2 ADC cycle
#define AVG        1000  // Average sample limit
#define ZOFFSET    0x00  // Average Zero offset
#define BUF_SIZE   16  // Sample buffer size
#define	LED_TIME   300

//function prototype
void delay(unsigned long i);

// Global variable for this example
Uint16 AdcSampleTable[BUF_SIZE];
unsigned int ADC_Result;
unsigned long proba;

main()
{
   Uint16 i;


// Step 1. Initialize System Control:
// PLL, WatchDog, enable Peripheral Clocks
// This example function is found in the DSP280x_SysCtrl.c file.
   InitSysCtrl();

// Specific clock setting for this example:
   EALLOW;
   SysCtrlRegs.HISPCP.all = ADC_MODCLK;	// HSPCLK = SYSCLKOUT/ADC_MODCLK
   EDIS;

// Step 2. Initialize GPIO:
// This example function is found in the DSP280x_Gpio.c file and
// illustrates how to set the GPIO to it's default state.
// InitGpio();  // Skipped for this example
// Enable the pin GPIO34 as output
   EALLOW;
   GpioCtrlRegs.GPBMUX1.bit.GPIO34 = 0;    // GPIO pin
   GpioCtrlRegs.GPBDIR.bit.GPIO34 = 1;     // Output pin
   EDIS;

// Step 3. Clear all interrupts and initialize PIE vector table:
// Disable CPU interrupts
   DINT;

// Initialize the PIE control registers to their default state.
// The default state is all PIE interrupts disabled and flags
// are cleared.
// This function is found in the DSP280x_PieCtrl.c file.
   InitPieCtrl();

// Disable CPU interrupts and clear all CPU interrupt flags:
   IER = 0x0000;
   IFR = 0x0000;

// Initialize the PIE vector table with pointers to the shell Interrupt
// Service Routines (ISR).
// This will populate the entire table, even if the interrupt
// is not used in this example.  This is useful for debug purposes.
// The shell ISR routines are found in DSP280x_DefaultIsr.c.
// This function is found in DSP280x_PieVect.c.
   InitPieVectTable();

// Step 4. Initialize all the Device Peripherals:
// This function is found in DSP280x_InitPeripherals.c
// InitPeripherals(); // Not required for this example
   InitAdc();         // For this example, init the ADC

// Clear SampleTable
   for (i=0; i<BUF_SIZE; i++)
   {
     AdcSampleTable[i] = 0;
   }

   Gpio_select();

// Start SEQ1
//   AdcRegs.ADCTRL2.all = 0x2000;

   for(;;)
   {  // Take ADC data and log them in SampleTable array

       // Wait for INT1
       while (AdcRegs.ADCST.bit.INT_SEQ1== 0){}	   

       AdcRegs.ADCST.bit.INT_SEQ1_CLR = 1;

	   AdcSampleTable[0] = AdcRegs.ADCRESULT0>>4;
	   AdcSampleTable[1] = AdcRegs.ADCRESULT1>>4;
	   AdcSampleTable[2] = AdcRegs.ADCRESULT2>>4;
	   AdcSampleTable[3] = AdcRegs.ADCRESULT3>>4;
	   AdcSampleTable[4] = AdcRegs.ADCRESULT4>>4;
	   AdcSampleTable[5] = AdcRegs.ADCRESULT5>>4;
	   AdcSampleTable[6] = AdcRegs.ADCRESULT6>>4;
	   AdcSampleTable[7] = AdcRegs.ADCRESULT7>>4;
	   AdcSampleTable[8] = AdcRegs.ADCRESULT8>>4;
	   AdcSampleTable[9] = AdcRegs.ADCRESULT9>>4;
	   AdcSampleTable[10] = AdcRegs.ADCRESULT10>>4;
	   AdcSampleTable[11] = AdcRegs.ADCRESULT11>>4;
	   AdcSampleTable[12] = AdcRegs.ADCRESULT12>>4;
	   AdcSampleTable[13] = AdcRegs.ADCRESULT13>>4;
	   AdcSampleTable[14] = AdcRegs.ADCRESULT14>>4;
	   AdcSampleTable[15] = AdcRegs.ADCRESULT15>>4;


	   ADC_Result = AdcRegs.ADCRESULT15>>4;  	//read AN_TR(analog trimer) value     

	   GpioDataRegs.GPASET.bit.GPIO11    = 1;	//turn_off led

       delay(LED_TIME*(unsigned long)ADC_Result);	//software delay         			               

       GpioDataRegs.GPACLEAR.all    =BIT11;  //turn_on led    			  
  
       delay(LED_TIME*(unsigned long)ADC_Result);

	}
}


void delay(unsigned long i)
{    	
	unsigned long j;
    for (j = 0; j < i; j++) {}
}
//===========================================================================
// No more.
//===========================================================================


